@@ -1,11 +1,9 @@
+#![doc = include_str ! ("../README.md")]
+
 extern crate proc_macro;
 
 use proc_macro::TokenStream;
 
-use apps::apps_transform;
-use mock::mock_transform;
-use record::record_transform;
-
 mod mock;
 mod record;
 mod apps;
@@ -56,7 +54,7 @@ mod apps;
 #[proc_macro_attribute]
 pub fn mock(args: TokenStream, item: TokenStream) -> TokenStream {
     let args = syn::parse_macro_input!(args as syn::AttributeArgs);
-    mock_transform(args, item.into()).unwrap().into()
+    mock::mock_transform(args, item.into()).unwrap().into()
 }
 
 /// Starts a Stubr recorder server and creates a `recorder` variable which can be used to call the server e.g. `stubr.isahc_client()`.
@@ -96,7 +94,7 @@ pub fn mock(args: TokenStream, item: TokenStream) -> TokenStream {
 #[proc_macro_attribute]
 pub fn record(args: TokenStream, item: TokenStream) -> TokenStream {
     let args = syn::parse_macro_input!(args as syn::AttributeArgs);
-    record_transform(args, item.into()).unwrap().into()
+    record::record_transform(args, item.into()).unwrap().into()
 }
 
 /// Starts a Stubr server for each remote app name supplied.
@@ -118,5 +116,5 @@ pub fn record(args: TokenStream, item: TokenStream) -> TokenStream {
 #[proc_macro_attribute]
 pub fn apps(args: TokenStream, item: TokenStream) -> TokenStream {
     let args = syn::parse_macro_input!(args as syn::AttributeArgs);
-    apps_transform(args, item.into()).unwrap().into()
+    apps::apps_transform(args, item.into()).unwrap().into()
 }
